package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````(!8``#0````TI````````#0`(``(
M`"@`'0`<``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````1)$`
M`$21```%`````!````$```#8G@``V*X``-BN``!@`@``K`(```8`````$```
M`@```.R>``#LK@``[*X``.````#@````!@````0````$````3`$``$P!``!,
M`0``+````"P````$````!````%#E=&3<B0``W(D``-R)```T`0``-`$```0`
M```$````4N5T9-B>``#8K@``V*X``"@!```H`0``!`````$````O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```'````!`````$```!.971"4T0```#*FCL$````
M!`````,```!085@``````&$```!E```````````````J````"@``````````
M````,@````L````[`````````"D``````````0```$8```!=`````````!H`
M``!%````!````!D````0````%@```#T```!2````60````````!1````-P``
M`%0``````````````&$```!C````)P```%````!3````/@```&````!8````
M/P````````!"````'````"\```!7````(````"0`````````!0```$@`````
M````"````"8```!D````5@```$0````S````20```&(`````````6P``````
M```4````*````$<````````````````````.````+```````````````7```
M`"4`````````!P`````````>````-`````````!*`````P```$``````````
M-@````````````````````````!#`````````#4```!-````7@````````!?
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````/````````````````````````````````````
M`````!T````;`````````",``````````````"$````B```````````````)
M`````````!@````7````+@```!4````````````````````-`````````"T`
M```K````,0`````````````````````````````````````````\````'P``
M`````````````````!(``````````````#H````"````!@``````````````
M`````#D```!,`````````!,``````````````$\``````````````#@`````
M`````````$L`````````00````P`````````3@```!$```!5````,````%H`
M`````````````````````````````)@``````````````!(````,````````
M```````2````%```````````````$@```'\#```N(0```P```!(`#``<````
M```````````B````*P``````````````$@```$@#`````````````!(````Q
M```````````````2````D`,``$$J```K````$@`,`#@``````````````!(`
M``!5`P`````````````2````0```````````````$@```*L#``#\-```<```
M`!(`#`"#```````````````2````2```````````````$@```+<#```XL0``
M`````!``%P!8```````````````2````9P``````````````$@```&T`````
M`````````!(```!T```````````````2````?@``````````````$@```(@`
M``!@20```````!``#0".```````````````2````EP``````````````$@``
M`!D"`````````````!(```"=```````````````2````JP``````````````
M$0```,0"`````````````"(```"X```````````````2````O@,``%\C```\
M````$@`,`,L#``";(P``7````!(`#`#7`P``*"L``'\'```2``P`Q@``````
M````````%@```-D``````````````!(```!G`P`````````````2````Y```
M````````````$@```.T```"`L0``!````!$`&`#U```````````````2````
M_@``````````````$@```#X#`````````````!(````*`0`````````````2
M````Y`,``/]"```1`@``$@`,`!T!`````````````!$````O`0``````````
M```2````/P$`````````````$@```$T!`````````````!(```!2`0``````
M```````1````80$`````````````$@```.\#```TL0``!````!$`%P!P`0``
M```````````2````?`$`````````````$@```(P!`````````````!(```"A
M`0`````````````2````K`$`````````````$@```'H#``"$L0```````!``
M&`#_`@`````````````2````OP$`````````````$@```"H$```@%@``````
M`!(`#`#-`0`````````````2````U0$`````````````$@```.$!````````
M`````!(```#Y`P``]R,``-L#```2``P`YP$`````````````$@```/(!````
M`````````!(````&!```$$4``-$!```2``P``P(`````````````$@```!`$
M```XL0```````!``&``<!```=2```%`````2``P`)`0```!'``!,`@``$@`,
M``H"`````````````!(```"L`@`````````````B````*00``"`6````````
M$@`,`!$"`````````````!(````Q!```,2$``"X"```2``P`/@0``&PJ``"\
M````$@`,`!@"`````````````!(```!0!```TB<``%@````2``P`(0(`````
M````````$@```.@"`````````````!(````R`@`````````````@````1@(`
M````````````$@```%T"`````````````!(```!>!```*B@``#\````2``P`
M;`(`````````````$@```'4"`````````````!(```![`@`````````````2
M````,0,`````````````$@```(`"`````````````!(````D`P``0+$```0`
M```1`!@`B`(`````````````$@```%P#`````````````!(```"/`@``````
M```````2````9@0``*1"``!;````$@`,`)8"`````````````!$````9`P``
M_+````0````1`!<`:00``"`2````````$``)`&\$``"G,@``50(``!(`#``6
M`0`````````````2````FP(`````````````$@```&X#`````````````!(`
M````;&EB<&5R;"YS;P!R96%L;&]C`&UE;6UO=F4`7U]C>&%?9FEN86QI>F4`
M<FUD:7(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T7T1Y;F%,;V%D97(`
M<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T870U,`!P97)L7V9R
M964`7V9I;FD`7U]S=&%T-3``7V5X:70`<&5R;%]D97-T<G5C=`!03%]D;U]U
M;F1U;7``4&5R;%]S=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A
M;&QO8P!C;&]S961I<@!E;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E
M=&-H<'8`7U]S<')I;G1F7V-H:P!R96%D`%!,7VUE;6]R>5]W<F%P`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?9V5T7W-V`%]?7W1L<U]G971?861D<@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-Y<U]T97)M`%]?97)R;F\`4&5R;%]M9U]S970`;6MD:7(`<&5R;%]P
M87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR`'9F
M<')I;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!?
M7W-T86-K7V-H:U]F86EL7VQO8V%L`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?<G5N
M`&QS965K`&]P96X`<W!R:6YT9@!G971U:60`<W1R;&5N`%]?<T8`<W1R8VUP
M`&QI8FTN<V\N,`!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!?7W)E9VES=&5R
M7V9R86UE7VEN9F\`;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS
M;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!?961A=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M
M:W1M<&1I<@!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`<VAA
M7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`;6%I;@!?7W-T87)T`'!A<E]F
M:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'!A<E]D
M:64`<VAA7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`"]U<W(O<&MG+VQI
M8B]P97)L-2\U+C0P+C`O:3,X-BUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z
M+W5S<B]P:V<O;&EB````\*\```@```#\L```"`````"Q```(````-+$```@`
M``#,KP``!@4``-"O```&#P``U*\```8;``#8KP``!AP``-RO```E(0``X*\`
M``8K``#DKP``!B\``.BO```&-@``[*\```9'``#TKP``!DX``/BO```&4```
M_*\```9>```,L```!P$``!"P```'`@``%+````<#```8L```!P8``!RP```'
M!P``(+````<(```DL```!PH``"BP```'"P``++````<,```PL```!PX``#2P
M```'$0``.+````<2```\L```!Q,``$"P```'%```1+````<5``!(L```!Q<`
M`$RP```'&```4+````<9``!4L```!QH``%BP```''0``7+````<B``!@L```
M!R,``&2P```')```:+````<F``!LL```!R<``'"P```'*```=+````<I``!X
ML```!RP``'RP```'+0``@+````<N``"$L```!S```(BP```',@``C+````<S
M``"0L```!S0``)2P```'-0``F+````<X``"<L```!SD``*"P```'.P``I+``
M``<\``"HL```!ST``*RP```'/P``L+````=```"TL```!T(``+BP```'1@``
MO+````=)``#`L```!TP``,2P```'3P``R+````=1``#,L```!U(``-"P```'
M5```U+````=5``#8L```!U8``-RP```'5P``X+````=8``#DL```!UH``.BP
M```'6P``[+````=<``#PL```!V(``/2P```'8P``^+````=D````````````
M``````!5B>7H7P<``,G#````````_[,$````_Z,(`````````/^C#````&@`
M````Z>#_____HQ````!H"````.G0_____Z,4````:!````#IP/____^C&```
M`&@8````Z;#_____HQP```!H(````.F@_____Z,@````:"@```#ID/____^C
M)````&@P````Z8#_____HR@```!H.````.EP_____Z,L````:$````#I8/__
M__^C,````&A(````Z5#_____HS0```!H4````.E`_____Z,X````:%@```#I
M,/____^C/````&A@````Z2#_____HT````!H:````.D0_____Z-$````:'``
M``#I`/____^C2````&AX````Z?#^____HTP```!H@````.G@_O___Z-0````
M:(@```#IT/[___^C5````&B0````Z<#^____HU@```!HF````.FP_O___Z-<
M````:*````#IH/[___^C8````&BH````Z9#^____HV0```!HL````.F`_O__
M_Z-H````:+@```#I</[___^C;````&C`````Z6#^____HW````!HR````.E0
M_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^____HWP```!HX```
M`.D@_O___Z.`````:.@```#I$/[___^CA````&CP````Z0#^____HX@```!H
M^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(`0``Z=#]____HY0`
M``!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG````&@@`0``Z:#]____
MHZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^CJ````&@X`0``Z7#]
M____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W___^CM````&A0`0``
MZ4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I(/W___^CP````&AH
M`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!``#I\/S___^CS```
M`&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````:)`!``#IP/S___^C
MV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@````:*@!``#ID/S_
M__^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/___Z/L````:,`!``#I
M8/S___^C\````&C(`0``Z5#\____H_0```!HT`$``.E`_/___Z/X````:-@!
M``#I,/S___^CS/___V:0_Z/8____9I#_H^S___]FD/^C^/___V:04U+HDP$`
M`&:09I!FD&:0D%6)Y593Z!(S```%QID``(V8V/[__XVPV/[__SGS<PG_$X/#
M!#GS<O=;7EW#58GE5U93@^P$Z.HR``"!QY:9``")??"+4`P#4`2+`(U,D`B+
M`87`="R[__\``#'2ZQ*#^`,/A-8```"#P0B+`87`=":#^`5T%(/X!W7DBT$$
MA<!TYH/$!%M>7UW##[=9!(/!"(L!A<!UVH72=.=F@_O_=.'!XP6-#!HYRG/7
M,?^#SO_K$8/[!G4%B=8K<@B#PB`YT780BQJ#^P)UZ(G7@\(@.=%W\(7_=*N#
M_O]TIHM?"`'SBPN%R72;,=+K$8/Y$G4#BT,$@\,(BPN%R703@_D1=>J+4P0!
M\H/#"(L+A<EU[0'0.<)R$NEH____`3.#P@@YT`^&6____XL:`?,/MDH$@_D(
M=.:#^2ITX^F#+P``BU$$Z2+___]5B>575E.#[`3HR3$```5]F```B47PQ\,`
M````Q\8`````.?-S%X![!"H/A5,O``"+._\7B0>#PP@Y\W+I@\0$6UY?7<-5
MB>575E.#[!SHB#$``('#.)@``(M]"(MU#(GPZ('^__^%]@^$]0```(V#0`$`
M`(DPC8.``0``B<&)1>R+1@B)`8L&BQ"%T@^$O@```(V+_````(D1BP`/MA"$
MTG01@\`!@/HO=?&)`0^V$(32=>^%_W0(B3PDZ'OZ___H=OW__XN#\/___X7`
M#X3*````C8/8_O__B47PC;O8_O__.<=S"O\7@\<$.WWP<O:-@S!F__^)!"3H
M/?K__XV#V/[__XE%\(V[V/[__SG'<PK_%X/'!#M]\'+VC8-@F?__B00DZ!+Z
M___H??G__XM%[(L`B40D"(L&B40D!(M&!(D$).A#+@``B00DZ'OY__^-@_P`
M``"-DT0!``")$.E1____QT0D$!,```"-@VR9__^)1"0,QT0D"`(```#'!"0$
M````QT0D!`````#HROK__\<$)`$```#H+OK__^A>_O__Z2S___^+'"3#4U>#
M[`CH\O___X'#UI8``("[)0$```!U2,:#)0$```&#N\S___\`=`Z+@P`!``")
M!"3HJ?S__XV[Y/[__XL'A<!T!__0@\<(Z_.#N^S___\`=`Z-@XS<__^)!"3H
MC_S__X/$"%];PU-7@^P(Z(O___^!PV^6``"`NR0!````=5G&@R0!```!@[O8
M____`'08C;L$`0``B7PD!(V[C-S__XD\).A`_/__@[OX____`'04C;OH_O__
MBS^%_W0(B3PDZ#/\__^-N]C^__^+!X/X_W0'_]"#[P3K\H/$"%];PY!5B>57
M5E.#[!SH0B\``('#\I4``(E%[(E5Y(7`#X2A````B<*-@X`!``"+`(E%Z(7`
M#X2,````#[8"B=:$P`^$BP```#P]=`J#Q@$/M@:$P'7R*W7LB77PBW7HBSZ%
M_W0TB?B)]XG&BT7PB40D"(M-[(E,)`2)-"3H(_C__X7`=0F+1?"`/`8]=!6#
MQP2+-X7V==2)]XGX@\0<6UY?7<.)\(G^B<>)\2M-Z,'Y`HM%Y(D(BT7PC7P'
M`8GX@\0<6UY?7<,Q_XGX@\0<6UY?7</'1?``````ZX!5B>575E.![*0```#H
M9RX``('#%Y4``(G&B[O@____BP>)1?`QP(7V=`6`/@!U%HM%\"L'#X50`0``
M@<2D````6UY?7<.)-"3HF_C__XF%</___X7`=-B-@X"9__^)A6C___^-A73_
M__^)A63___^+A7#___^)!"3HF_K__X7`#X3#````C5`-@'@-+G4&@'H!`'3;
M@'@-+@^$Q0```(F5;/___XDT).@\^O__B85@____BY5L____B10DZ"CZ__^+
MC6#___^-1`$"B00DZ";Z__^+E6S___^)5"0,B70D"(N-:/___XE,)`2)A6S_
M__^)!"3HP/G__XN-9/___XE,)`2+A6S___^)!"3H2/?__X/X_W02BX5\____
M)0#P```]`$```'16BX5L____B00DZ//V__^+A6S___^)!"3HM?;__^DG____
MBX5P____B00DZ'+W__^)-"3H.O;__^G,_O__@'H!+@^%,?___X!Z`@`/A/C^
M__^0Z2'___^+A6S____H>/[__^NKZ,GX__]5B>575E.![(@```#HV"P``('#
MB),``(G&B[O@____BP>)1?`QP(V%=/___XE$)`2)-"3H<?;__X7`=3:+E7S_
M__^!X@#P``"!^@!```!T"('Z`*```'4<QT0D!`(```")-"3H$?C__X7`#Y3`
M#[;`ZP(QP(M-\"L/=0N!Q(@```!;7E]=P^@^^/__58GE5U93@>P0!```Z$TL
M``"!P_V2``"+L^#___^+%HE5\#'2QT0D"``$``")1"0$C;WP^___B3PDZ%#U
M__^#Z`$Y^'<,ZP_&``"#Z`$Y^'0%@#@O=/''1"0$+P```(D\).AH]?__A<!T
M(SGX=QJ)/"3HN/?__XM-\"L.=2"!Q!`$``!;7E]=P\8``.OAC8.&F?__B00D
MZ)/W___KV>B<]___58GE5U93@^3P@>P@!```Z*@K``"!PUB2``")1"08B50D
M%(N[X/___XL'B80D'`0``#'`QT0D"/\#``"-="0<B70D!(V#B)G__XD$).C+
M]?__A<!^6HU0_X!\!!L`#X6%````A=)T2(E4)`B)5"00QT0D!"\```")-"3H
M[?;__X7`="R+5"00B50D#(ET)`B+1"08B40D!&6A`````"N#W/___XL`B00D
MZ/_V___K)HM$)!2)1"0(BT0D&(E$)`1EH0`````K@]S___^+`(D$).@']?__
MBX0D'`0``"L'=0^-9?1;7E]=PXG"Z7C____HJ/;__U6)Y5=64X/L+.BZ*@``
M@<-JD0``B47HB=:+@^#___^)1=R+"(E-\#')@#H]=0.#Q@&)-"3H__;__XE%
MX(U5[(M%Z.@Q^___B<>%P`^$U````(D$).C?]O__.47@#X:M````BT7LC0R%
M`````(V#@`$``(E%Y(M%Z`^V$(32=0_I40$``(/``0^V$(32=`6`^CUU\2M%
MZ(M]Y`,/B<^+3>"-1`@"B00DZ)SV__^)!X7`=$>+?>2+!XM5[(L,D(M%Z(U0
M`0^V`(@!A,!U$.M3@\(!#[9"_XA'`83`=$6)SXU)`3P]=>G&!STQP`^V%`:(
M5`<!@\`!A-)U\8M%W(MU\"LP#X7A````@\0L6UY?7<,QP`^V%`:(%`>#P`&$
MTG7RZ]B)S^O`C8.``0``B47DBQ"+.H7_#X2B````,?^)^(/'`8L,NH7)=?2-
M!(4,````BXM(`0``A<EU5XE5V,>#2`$```$```")!"3HVO7__X7`=(>-#+T`
M````B4PD"(E-U(M5V(E4)`2)1=B)!"3H1O+__XM-Y(M%V(D!BTW4BT78QT2X
M!`````")?>SIQ?[__XE$)`2)%"3H#/+__XE%V(M-Y(D!A<`/A"W___^-#+T`
M````Z\@QP.FZ_O__N`@````Q_^EG____Z+OT__]5B>53@^3P@^P0Z,PH``"!
MPWR/``"-@]#9__^)1"0,BX/0____B40D"(V#FIG__XE$)`1EH0`````K@]S_
M__^+`(D$).BB\___BUW\B>Q=PU6)Y593@^3P@^P@Z'LH``"!PRN/``!EH0``
M```K@]S___^)QHL`B00DZ(+____'1"04`````(V#?YG__XE$)!")1"0,C8.G
M@O__B40D"(V#MIG__XE$)`2+!HD$).BI\___C67X6UY=PS'`PU6)Y5=64X'L
MN`0``.@.*```@<.^C@``BT4(B85L^___BWT,BXO@____B8U<^___BQ&)5?`Q
MTHV5</O__XV#RYG__^B(^/__B<;'1"0$+P```(N%;/O__XD$).@`\?__A<!T
M,8NU;/O__XGRC8/4F?__Z.'\__^)\(N-7/O__XM5\"L1#X6@`0``@<2X!```
M6UY?7<.)/"3H4_/__XV+X9G__XF-:/O__XE,)`2)!"3HJ_'__XG'A<!TJ8V#
MAIG__XF%6/O__XV#R)K__XF%8/O__X`_``^$_P```(7V=!2)?"0$B30DZ,3S
M__^%P`^$O@```(D\).B4\___B<*-1`?_.<=R#.L9Q@``@^@!.<=T!8`X+W3Q
MB3PDZ''S__^)PHF59/O__XN%;/O__XD$).A;\___BY5D^___C40"`3W_`P``
M#X<:____BX5L^___B40D&(N%8/O__XE$)!2)?"00C8/KFO__B40D#,=$)`@`
M!```QT0D!`````"-O?#[__^)/"3H1O'__XV%=/O__XE$)`2)/"3H9/#__X7`
M=1*+A7S[__\E`/```#T`@```=$J+A6C[__^)1"0$QP0D`````.B8\/__B<>%
MP`^$DO[__X`_``^%`?___X7V=`6`/BYT$+H!````B[U8^___Z2W___^`?@$`
M=+CKZ,=$)`0!````B3PDZ*3Q__^%P'6BB?J-@]29___H._O__XD\).C+\?__
MZ4_^___HT?'__U6)Y593@^P(Z.0E``"!PY2,``"+=0C'1"0$+P```(DT).@[
M[___A<!T`XUP`8DT).B,\?__@\0(6UY=PU6)Y593@^P$Z*@E``"!PUB,``"+
M=0B%]G0D@#X`=!^)-"3H_O'__X/``3T`!```=R*)\(/$!%M>7>D9^?__C8.&
MF?__B00DZ#GQ__^#Q`1;7EW#,<"#Q`1;7EW#58GE5U93@^P0Z$<E```%^XL`
M`(E%Z(N(X/___XE-Y(LYB7WP,?^-7>R-L..9__^-N(`!``")VHGPZ,OU__^%
MP'0JBP>+5>R-!)"+4`2)$(72=.*#P`2+4`2)$(72=?2)VHGPZ*'U__^%P'76
MBT7HC;#LF?__C;B``0``B=J)\.B%]?__A<!T*HL'BU7LC020BU`$B1"%TG3B
M@\`$BU`$B1"%TG7TB=J)\.A;]?__A<!UUHM%Z(VP])G__XVX@`$``(G:B?#H
M/_7__X7`="J+!XM5[(T$D(M0!(D0A=)TXH/`!(M0!(D0A=)U](G:B?#H%?7_
M_X7`==:+1>B-L/V9__^-N(`!``")VHGPZ/GT__^%P'0JBP>+5>R-!)"+4`2)
M$(72=.*#P`2+4`2)$(72=?2)VHGPZ,_T__^%P'76BT7HC;`$FO__C;B``0``
MB=J)\.BS]/__A<!T*HL'BU7LC020BU`$B1"%TG3B@\`$BU`$B1"%TG7TB=J)
M\.B)]/__A<!UUHM%Z(VP%)K__XVX@`$``(G:B?#H;?3__X7`="J+!XM5[(T$
MD(M0!(D0A=)TXH/`!(M0!(D0A=)U](G:B?#H0_3__X7`==:+1>B-L,N9__^-
MN(`!``")VHGPZ"?T__^%P'0JBP>+5>R-!)"+4`2)$(72=.*#P`2+4`2)$(72
M=?2)VHGPZ/WS__^%P'76BT7HC;`@FO__C;B``0``B=J)\.CA\___A<!T*HL'
MBU7LC020BU`$B1"%TG3B@\`$BU`$B1"%TG7TB=J)\.BW\___A<!UUHM%Z(VP
M*IK__XVX@`$``(G:B?#HF_/__X7`="J+!XM5[(T$D(M0!(D0A=)TXH/`!(M0
M!(D0A=)U](G:B?#H<?/__X7`==:+1>B-L#2:__^-N(`!``")VHGPZ%7S__^%
MP'0JBP>+5>R-!)"+4`2)$(72=.*#P`2+4`2)$(72=?2)VHGPZ"OS__^%P'76
MBT7HC;#4F?__C;B``0``B=J)\.@/\___A<!T*HL'BU7LC020BU`$B1"%TG3B
M@\`$BU`$B1"%TG7TB=J)\.CE\O__A<!UUHG:BWWHC8<^FO__Z-'R__^)PH7`
M=`N-ARJ:___H2/?__XG:BWWHC8=/FO__Z+#R__^)PH7`=`N-AV&:___H)_?_
M_XG:BWWHC8=LFO__Z(_R__^)PH7`=#"-A\N9___H!O?__XM%Y(M-\"L(=3Z+
M1>B-D(V:__^-@`2:__^#Q!!;7E]=Z>'V__^)VHM]Z(V'?)K__^A)\O__B<*%
MP'3%C8<@FO__Z,#V___KN(M=Z.A>[?__58GE5E.#[`CH<2$``('#(8@``(NS
MX/___XL&B47T,<"-5?"-@R":___H`/+__X7`=!T/M@"$P'06/#`/E<`/ML"+
M3?0K#G4+@\0(6UY=PS'`Z^[H!NW__U6)Y5.#[`SH&B$``('#RH<``(U%#(E$
M)`B+10B)1"0$BX/\____!;````")!"3HL^S__\<$)/\```#HU^G__U6)Y5=6
M4X'L-``!`.C6(```@<.&AP``B40D)(NSX/___XET)!"+/HF\)#```0`Q_\=$
M)`P"````QT0D!`````#'1"0(`````(D$).BG[/__@\#_@]+_B<:)UP^WP(E$
M)!R)T"4```"`B40D((M$)!R+5"0@A=)Y)8/`_XE$)!R+1"0<#0``__^Y____
M_XG*@\`!@](`B40D'(E4)"`K="0<&WPD((U,)"B%_P^([P```(V#CYK__XE$
M)!B-@YR:__^)1"04B4PD',=$)`P`````B70D!(E\)`B+1"0DB00DZ!+L__\A
MT(/X_XM,)!P/A,H```#'1"0("``!`(E,)`2)3"0<BT0D)(D$).B7ZO__@_C_
MBTPD'`^$CP```(/X!W9BC40!^#G(<EJ-%2@!``")="0<B7PD(.L'@^@!.<AR
M.XL\&CDX=?*+LRP!```Y<`1UYXMT)!R+?"0@*<B9`?`1^HM\)!"+M"0P``$`
M*S=U8H'$-``!`%M>7UW#BW0D'(M\)""!Q@``__^#U_^)^O?2B?`U``#__PG"
M#X4E____N/____^Z_____^NVBT0D%(D$).@)_O__BTPD'.O&BT0D&(D$).CW
M_?__BTPD'.DA____Z._J__]5B>53@^P$Z`,?``"!P[.%``#H2.O__XD$).@@
MZ___A<!T`HL`@\0$6UW#58GE5U93@^PDZ-8>``"!PX:%``"+10B)1>B+N^#_
M__^+!XE%\#'`C57LC8.HFO__Z%_O__^%P'0'B<:`.`!U'(M%\"L'=7"+5>B-
M@ZB:__^#Q"1;7E]=Z<#S__^+1>B)!"3H[>K__XE%Y(DT).CBZO__BU7DC40"
M`HD$).CCZO__B<*)="00C8/AF?__B40D#(M%Z(E$)`B-@^N:__^)1"0$B10D
MB57HZ'?J__^+1?`K!XM5Z'23Z`CJ__]5B>575E.![!P!``#H%QX``('#QX0`
M`(M%"(F%!/___XN#X/___XF%^/[__XL(B4WP,<F-@\2:__^)A13___^-@X:9
M__^)A1C____'A1S___\`````C8-:FO__B84P____C8/*FO__B84T____C8-W
MFO__B84X____C8/2FO__B84\____QX5`____`````(V#N)K__XF%#/___XF%
M(/___XV#UIK__XF%)/___\>%*/___P````"-O1#___^)^HV#RYG__^@.[O__
MA<!T"XG&@#@`#X7U!```Z#O^__^)PH7`#X2#!```B10DB94,____Z*+I__^-
M1``!B00DZ*;I__^)A0C___^+E0S___\/M@*$P'1(B[4(____C8O?FO__B8T,
M____B;T`____B?>)U@^VP(E$)`B+A0S___^)1"0$B3PDZ![I__^#Q@&#QP(/
MM@:$P'7:B[T`____C;4L____C8-AFO__B;T,____B??K"8/'!(L'A<!T-8N5
M#/___^A1[?__B<:%P'3F@#@`=.'HJ.___X7`=-B+O0S___^)-"3H3^C__XG"
MA<!U5NL&B[T,____BY44____C;44____B;T,____B=?K"HM^!(7_="F#Q@2`
M/P!T(8GXZ%SO__^%P'3FB3PDZ`GH__^%P'3:B<*+O0S____K"(N]#/___S'2
MB10DB94,____Z(7H__^)QHN%"/___XD$).AUZ/__C;0&!`0``(DT).AVZ/__
MB<&+A0C___^)1"04C8/DFO__B40D$(V#R)K__XF%"/___XE$)`R+E0S___^)
M5"0(C8/IFO__B40D!(F-#/___XD,).CNY___QT0D!,`!``"+C0S___^)#"3H
M^.;__X/X_P^$=P(``(V%1/___XE$)`2+A0S___^)!"3H-^7__XF%]/[__X7`
M=%^+A0S___^)1"0,BX4$____BP")1"0(C8.<F___B40D!(N#_/___P6P````
MB00DZ#KE___'A?S^__\`````BX7X_O__BTWP*P@/A7$$``"+A?S^__^!Q!P!
M``!;7E]=PXN%3/___R4`\```/0!```!UCXN%7/___XF%`/___^@[Y___.84`
M____#X5R____BX5,____)?\!```]P`$```^%7/___XDT).A!Y___B87\_O__
MB?J-@[.:___H7NO__X7`#X1G`@``B40D!(N%!/___XL`B00DZ'/R__^)A0#_
M__^%P`^$10(``(NU`/___XDT).CFYO__@_@#=C6-=`;\N04```"-N_*:___S
MI@^7PH#:`(32=1J#^`0/A$@#``"+M0#___^`?`;[+P^$-P,``.BY^/__A<!U
M'L=$)`0`````BX4`____B00DZ#WF__^%P`^%Z0$``(V3C9K__XV#()K__^@\
M[___Z)_E__^-LW^9__^)="04B40D$(N%"/___XE$)`R+A0S___^)1"0(C8,6
MF___B40D!(N%_/[__XD$).@%YO__C;LDF___B;4$____B[7T_O__B;T`____
MB[W\_O__ZTKHX.3__X,X$755@\8!Z#/E__^+C03___^)3"08B70D%(E$)!"+
MA0C___^)1"0,BX4,____B40D"(N%`/___XE$)`2)/"3HF^7__\=$)`3``0``
MB3PDZ*OD__^#^/]TH8N%#/___XD$).BXXO__B[W\_O__B?J-@\N9___H7>[_
M_XD\).@Y^O__Z>C]___H4^3__X,X$0^$>_W__^A%Y/__BP")1"00BX4,____
MB40D#(N%!/___XL`B40D"(V#8)O__XE$)`2+@_S___\%L````(D$).C,XO__
MQX7\_O__`````.F-_?__C;4@____BX4,____ZPJ+1@2%P'0L@\8$B?KH3NG_
M_X7`=.N`.`!TYHD$).A=Y/__B<*%P`^%0_O__XM&!(7`==3'!"0-````Z/#D
M__^)A0C___^-D[V:__^X4P```.E'^___B00DZ&[Y__^)-"3H&N3__XF%_/[_
M_^D/_?__BX4$____BP")A0#____IJ/W__XF%!/___^@Z]___B<:)UX72#X@`
M_O__QT0D#`````"#P/:#TO^)1"0$B50D"(N-!/___XD,).@!Y/__QT0D"`8`
M``"-1<&)1"0$BXT$____B0PDZ)3B__^#^`:+C03___]T%(V#_)K__XD$).B5
M]O__BXT$____@7W!`$-!0P^%D_W__V:!?<5(10^%A_W__\=$)`P`````@\;.
M@]?_B70D!(E\)`B)#"2)C03____HB./__\=$)`@H````C77'B70D!(N-!/__
M_XD,).@;XO__@_@H=`Z-@_R:__^)!"3H(O;__\9%[P"-@W^9__^)1"04B70D
M$(N%"/___XE$)`R+A0S___^)1"0(C8,'F___B40D!(N%_/[__XD$).A*X___
MZ;_]__^+A03___^+4`2%T@^$N/S__XD4)(F5!/___^A6X___@_@##X:A_/__
MBY4$____C70"_+D%````C;OWFO__\Z8/E\`<`(3`#X5]_/__B94`____Z7+\
M___HB>+__U6)Y5=64X/D\(/L(.B8%@``@<-(?0``BX/@____B40D%(LXB7PD
M'#'_9:$`````*X/<____BP`/ME!DB%!EC7PD&(GZC8,$FO__Z`KG__^%P'0)
M@#@Q#X23`0``Z._P___'1"0,`P```,=$)`@!````C8,UF___B40D!&6A````
M`"N#W/___XG&BP")!"3HMN#__X7`=#2-DS>;__^)5"0(BU`,B40D$(L2B50D
M!(L6B10DZ!'@__^+1"00BT`,BP#V0`I`#X5*`0``QT0D#`,```#'1"0(`0``
M`(V#/)O__XE$)`1EH0`````K@]S___^)QHL`B00DZ$S@__^%P(E$)!!T,(GZ
MC8/4F?__Z$?F__^%P(M,)!`/A.````")1"0(BT$,BP")1"0$BP:)!"3HE-__
M_\=$)`@!````C8,^F___B40D!&6A`````"N#W/___XG&BP")!"3H*N#__XV3
M4YO__XE4)`B)1"0$BP:)!"3H4M___XL&QD!E`(GZC8/+F?__Z,_E__^)@TP!
M``"%P'0UQT0D!,`!``")!"3H9>#__X/X$70(C5`!@_H!=W>+1"04BWPD'"LX
M#X6/````C67T6UY?7<.+@U`!``")!"3HJO;__XF#3`$``(7`=;.-@_";__^)
M!"3HNM___X!X`0`/A&C^___I7O[__XM!#(N34`$``(L2BP#HW>C__^D@____
MB40D!(L&B00DZ-;?___IH_[__XE$)`R+@TP!``")1"0(BX-0`0``BP")1"0$
MC8,4G/__B00DZ%G?___H-.#__U6)Y5=64X/L".A&%```@</V>@``BT4(B<:)
M1?#HM?+__X7`=`F%]G0%@#X`=0B#Q`A;7E]=PXM%\(D$).A>[O__B00DZ!KN
M__^Y!````(V[Y)K__XG&\Z8/E\`<`(3`=<V+1?"#Q`A;7E]=Z6SE__]FD&:0
M58GE5U93@>QP`0``Z-,3``"!QW]Z``")O83^__^)PXF%G/[__XN_X/___XF]
MB/[__XL'B47P,<"-E;#^__^+3(,<#\F)#(*#P`&#^!!U[XU-L(M"-#-"(#-"
M"#,"T<")0D"#P@0YRG7IB[6<_O__BQZ+3@2+?@B+1@R)A:S^__^+5A"+A;#^
M__^)E8S^__^-E`*9>8):B=C!P`4!T(GZB[6L_O__,?(ARC'R`<*)C9#^__^)
MR,'(`HG&B?@Q\"'8B;VD_O__,?B+C;3^__^+O:S^__^-C`^9>8):`<B)T<'!
M!0'(B9V4_O__B=G!R0*)\XF-H/[__S'+B=DAT3'QB[VX_O__BYVD_O__C;P[
MF7F"6@'YB<?!QP4!SXF]J/[__\'*`HN]H/[__XG[,=.)V2'!,?F+G;S^__^-
MM!Z9>8):`?&+G:C^___!PP4!R\'(`HG1,<$CC:C^__\QT8NUP/[__XVT-YEY
M@EH!\8G>P<8%`<Z+O:C^___!SP*)P3'YB9V@_O__(=DQP8N=Q/[__XV4&IEY
M@EH!T8GRP<(%`<J)E:C^__^+E:#^___!R@*)^S'3B=DA\3'YBYW(_O__C9P8
MF7F"6@'9BX6H_O__P<`%B<,!R\'.`HG0,?`CA:C^__\QT(N-S/[__XV,#YEY
M@EH!R(G?P<<%`<>)O:#^__^+A:C^___!R`*)\3'!(=DQ\8N]T/[__XV\.IEY
M@EH!^8N]H/[__\''!0'/P<L"B<(QVB.5H/[__S'"BXW4_O__C8P.F7F"6@'*
MB?G!P04!RHF5J/[__XN5H/[__\'*`HG9,=$A^3'9B[78_O__C;0PF7F"6@'Q
MBX6H_O__P<`%B<8!SL'/`HG0,?@CA:C^__\QT(N-W/[__XV,"YEY@EH!R(GS
MP<,%`=B)A:#^__^+A:C^___!R`*)^S'#B=DA\3'YBYW@_O__C9P:F7F"6@'9
MBY6@_O__P<(%B=,!R\'.`HG",?(CE:#^__\QPHN-Y/[__XV,#YEY@EH!RHG?
MP<<%`=>)O:C^__^+E:#^___!R@*)\3'1(=DQ\8N]Z/[__XV\.)EY@EH!^8N%
MJ/[__\'`!8G'`<_!RP*)T#'8(X6H_O__,="+C>S^__^-C`Z9>8):`<B)^<'!
M!0'(B86@_O__BX6H_O__P<@"B=DQP2'Y,=F+M?#^__^-M#*9>8):`?&+E:#^
M___!P@6)U@'.P<\"B<*)O9C^__\Q^HN]H/[__R'Z,<*+C?3^__^-C`N9>8):
M`<J)\\'#!0'3B9VH_O__B?K!R@*+O9C^__^)^3'1(?&)^S'YB[WX_O__C80X
MF7F"6@'(BXVH_O__P<$%`<C!S@*)T3'Q(XVH_O__,=&+O?S^__^-O#N9>8):
M`?F)Q\''!0'YBYVH_O__P<L"B[T`____C;PZH>O9;HGR,=HQP@'ZB<_!QP4!
M^L'(`HN]!/___XV\/J'KV6Z)WC'&,<X!_HG7P<<%`?Z)S\'/`HN-"/___XV<
M"Z'KV6Z)P3'Y,=$!V8GSP<,%`=F)T\'+`HN5#/___XV4$*'KV6Z)^#'8,?`!
MT(G*P<(%`=#!S@*+E1#___^-O!>AZ]ENB=HQ\C'*`?J)Q\''!0'ZP<D"B[T4
M____C;P[H>O9;HGS,<LQPP'[B=?!QP4!^\'(`HG'BX48____C;0&H>O9;HG(
M,?@QT`'PB=[!Q@4!\,'*`HG6BY4<____C901H>O9;HGY,?$QV0'1B<+!P@4!
MT<'+`HN5(/___XV\%Z'KV6Z)\C':,<(!^HG/P<<%`?K!R`*)QXN%)/___XV$
M!J'KV6Z)WC'^,<X!QHG0P<`%`<;!R0*+A2C___^-G`.AZ]ENB?@QR#'0`=B)
M\\'#!0'8B=/!RP*+E2S___^-E!>AZ]ENB<\QWS'W`=>)PL'"!0'7P<X"BY4P
M____C8P1H>O9;HG:,?(QP@'*B?G!P04!RL'(`HG!BX4T____C80#H>O9;HGS
M,<LQ^P'#B=#!P`4!P\'/`HN%./___XVT!J'KV6Z)R#'X,=`!\(G>P<8%`?#!
MR@*)UHN5//___XV4$:'KV6Z)^3'Q,=D!T8G"P<(%`='!RP*+E4#___^-O!>A
MZ]ENB?(QVC'"`?J)S\''!0'ZP<@"B<>+A43___^-A`:AZ]ENB=XQ_C'.`<:)
MT,'`!0'&P<D"BX5(____C9P#H>O9;HGX,<@QT`'8B?/!PP4!V,'*`HN=3/__
M_XV\'Z'KV6Z)RS'3,?,!^XG'P<<%`=^)O:#^___!S@*)TPGS(<.)WXG3(?,)
M^XN]4/___XV\.=R\&X\!^XN]H/[__\''!0'?B;VH_O__P<@"B<>)\PG#BX6@
M_O__(<.)\2'Y"=F+G53___^-E!K<O!N/`=&+G:C^___!PP4!RXG"P<H"B?D)
MT2.-J/[__XF]H/[__R'7"?F+A5C___^-M`;<O!N/`?&)W\''!8G^`<Z+A:C^
M___!R`*)A:C^__^)T0G!(=F+A:C^__\AT`G!BX5<____B[V@_O__C80'W+P;
MCP'!B?#!P`4!R(G'B=C!R`*+G:C^__\)PR'SBXVH_O__(<$)V8N=8/___XV<
M&MR\&X\!V8GZP<(%B=,!R\'.`HG""?*)T8F]H/[__R'YB<(A\@G*BXUD____
MB[VH_O__C8P/W+P;CP'*B=_!QP4!UXF]J/[__XN5H/[__\'*`HGQ"=&)SR'?
MB?$AT0GYB[UH____C;PXW+P;CP'YBX6H_O__P<`%B<<!S\'+`HG0"=B+C:C^
M__\AP8G0(=@)R(N-;/___XV,#MR\&X\!R(GYP<$%`<B)A:#^__^+A:C^___!
MR`*)V0G!(?F)SHG9(<$)\8NU</___XVT,MR\&X\!\8N5H/[__\'"!8G6`<[!
MSP*)P@GZBXV@_O__(=&)PB'Z"<J+C73___^-C`O<O!N/`<J)\\'#!0':B96H
M_O__BY6@_O__P<H"B?L)TR'SB?DAT0G9BYUX____C9P8W+P;CP'9BX6H_O__
MP<`%B<,!R\'.`HG0"?"+C:C^__\AP8G0(?`)R(N-?/___XV,#]R\&X\!R(G?
MP<<%`<>)O:#^__^+A:C^___!R`*)\0G!B<\AWXGQ(<$)^8M]@(V\.MR\&X\!
M^8N]H/[__\''!0'/P<L"B<()VHN-H/[__R'1B<(AV@G*BTV$C8P.W+P;CP'*
MB?G!P04!RHF5J/[__XN5H/[__\'*`HG9"=$A^8G.B=DAT0GQBW6(C;0PW+P;
MCP'QBX6H_O__P<`%B<8!SL'/`HG0"?B+C:C^__\AP8G0(?@)R(M-C(V,"]R\
M&X\!R(GSP<,%`=B)A9C^__^+A:C^___!R`*)^PG#(?.)^8F%H/[__R'!"=F+
M79"-G!K<O!N/`=F+A9C^__^)PL'"!8G3`<N)G:C^___!S@*+G:#^__^)V@GR
MB=$AP8G:(?()RHM-E(V,#]R\&X\!RHN]J/[__\''!0'7B<+!R@*)\0G1(XVH
M_O__B?`AT`G!BT68C80#W+P;CP'(B?G!P04!R(F%H/[__XN=J/[__\'+`HG1
M"=DA^8G0(=@)P8M%G(VT!MR\&X\!\8N%H/[__\'`!0'!P<\"B?Z+?:"-E#K6
MP6+*B=\Q]S.]H/[__P'7B<C!P`4!QXN%H/[__\'(`HM5I(V<$];!8LJ)\C'"
M,<H!VHG[P<,%`=K!R0*+7:B-M![6P6+*B<,QRS'[`?.)UL'&!0'SP<\"BW6L
MC;0PUL%BRHG(,?@QT`'PB=[!Q@4!\,'*`HG6BU6PC901UL%BRHGY,?$QV0'1
MB<+!P@4!T<'+`HM5M(V\%];!8LJ)\C':,<(!^HG/P<<%`?K!R`*)QXM%N(V$
M!M;!8LJ)WC'^,<X!QHG0P<`%`<;!R0*+1;R-G`/6P6+*B?@QR#'0`=B)\\'#
M!0'8B=/!RP*+5<"-E!?6P6+*B<\QWS'W`=>)PL'"!0'7P<X"BU7$C8P1UL%B
MRHG:,?(QP@'*B?G!P04!RL'(`HG!BT7(C80#UL%BRHGS,<LQ^P'#B=#!P`4!
MP\'/`HM%S(VT!M;!8LJ)R#'X,=`!\(G>P<8%`?#!R@*)UHM5T(V4$=;!8LJ)
M^3'Q,=D!T8G"P<(%`='!RP*+5=2-O!?6P6+*B?(QVC'"`?J)S\''!0'ZP<@"
MB<>+1=B-A`;6P6+*B=XQ_C'.`<:)T,'`!0'&P<D"BT7<C9P#UL%BRHGX,<@Q
MT`'8B?/!PP4!V(G3P<L"BU7@C907UL%BRHG/,=\Q]P'7B<+!P@4!U\'.`HM5
MY(V,$=;!8LJ)VC'R,<(!RHGYP<$%`<K!R`*+3>B-G`O6P6+*B?$QP3'Y`=F)
MT\'#!0'9B8VH_O__P<\"BUWLBXV4_O__C9P9UL%BR@'>B<,Q^S'3`?.+C:C^
M___!P04!RXNUG/[__XD>BXVH_O__`XV0_O__B4X$P<H"`Y6D_O__B58(`[VL
M_O__B7X,`X6,_O__B480BX6(_O__BW7P*S!U"X'$<`$``%M>7UW#BYV$_O__
MZ(S2__]5B>53@^P$Z*`&``"!PU!M``#'!"1@````Z`[3___'``$C16?'0`2)
MJ\WOQT`(_MRZF,=`#'94,A#'0!#PX=+#QT`4`````,=`&`````#'0%P`````
M@\0$6UW#58GE5U93@^P,BUT,BT40P>`#BU4(,<D#0A0/DL&+4AB#^0&#VO^+
M30B)012+11#!Z!T!T(E!&(G(BTE<C5`<A<ET6+Y`````*<Z+11`Y\`^/.P$`
M`(E%\(T\"HG>@_@$#X,]`0``]D7P`G0"9J7V1?`!=`&DBWT(BT]<`<&)3UR#
M^4`/A=H```")5?`I11`!PXGXZ-GQ__^+5?"#?1`_#XX;`0``BT40@^A`B47L
MB<?![P:-=P'!Y@8!WHEU\(E]Z(G7B=Z+70B+!HD'BT8$B4<$BT8(B4<(BT8,
MB4<,BT80B4<0BT84B4<4BT88B4<8BT8<B4<<BT8@B4<@BT8DB4<DBT8HB4<H
MBT8LB4<LBT8PB4<PBT8TB4<TBT8XB4<XBT8\B4<\@\9`B=CH0?'__SMU\'63
MBW7PB?J+?>C!YP:+1>PI^(E%$(M%$(G7@_@$<R2H`G48J`%U$8M%"(M=$(E8
M7(/$#%M>7UW#I.OL9J6H`73FZ_7VP@%U6O?'`@```'5!B<'!Z0+SI:@"=,CK
MWHGPB47PC3P*B=Z#^`0/@L/^___WQP$```!U4_?'`@```'4YBTWPP>D"\Z7I
MIO[__XG>ZX0/MQ9FB1>#QP*#Q@*#Z`+KK@^V!HM="(A#'(/'`8/&`8M%$(/H
M`>N/#[<.9HD/@\<"@\8"@VWP`NNU#[8+B`^#QP&-<P&-2/^)3?#KFE6)Y5=6
M4X/L%.@N!```!>)J``")1?"+=0B+70R+4Q2)T`_(B47HBT,8#\B)1>S!Z@.#
MXC^->QR-0@'&!!>`C4P7`8/X.`^.^0```+I`````*<)T#3'`Q@0!`(/``3G0
M<O6)V.CX[___NC@````QP/?'`0````^%.@$``/?'`@````^%)`$``(G1P>D"
M\ZOVP@(/A00!``"#X@%T`:J+1>R)0U2+1>B)0UB)V.BP[___BP/!Z!B(!HL#
MP>@0B$8!BP.(9@*+`XA&`P^V0P>(1@0/MT,&B$8%BT,$B&8&BT,$B$8'#[9#
M"XA&"`^W0PJ(1@F+0PB(9@J+0PB(1@L/MD,/B$8,#[=##HA&#8M##(AF#HM#
M#(A&#P^V0Q.(1A`/MT,2B$81BT,0B&82BT,0B$83B1PDBUWPZ(3,__^#Q!1;
M7E]=P[HX````*<*)SS')@_H$<QGVP@)T!(G(9JN#X@$/A#?___^)R.DO____
M]\<!````=53WQP(```!U0X/Z!'+2B="#X/R)1>0QP(D,!X/`!#M%Y'+U`<?K
MN6:K@^(!#X3W_O__Z?'^__]FJX/J`NG2_O__JKHW````Z;O^__^)R&:K@^H"
MZ[2)R*J#Z@'KI&:09I!FD&:09I!FD&:0D(M=\.CXR___BUWPZ/#+__]5B>57
M5E.#Y/"#[$#H/P(``('#[V@``(M%#(E$)#2+11")1"0PBX/@____B40D*(LX
MB7PD/#'_C40D,(E$)`B-1"0TB40D!(U%"(D$).C.S/__BX/H____B40D"(E$
M)`2+@_3___^)!"3H`LW__XN#U/___X`X``^$(`$``&6A`````"N#W/___XL`
M@(A:`@```XM%"(UX`XE\)"R#P`0]____/P^';P$``,'@`HD$).@KS/__B<&)
M@U`!``"+="0TBP:)`8V#69O__XE!!(V#-`$``(L`B4$(C8-<F___B4$,BWT(
M@_\!#XY#`0``C48$C5$0C32^B4PD)(L(B0J#P`2#P@0YQG7RBTPD)(/'`\<$
MN0````#'1"00`````(E,)`R+1"0LB40D"(V#Q7#__XE$)`2+@U0!``")!"3H
M?<S__X7`#X2'````BX-4`0``B00DZ`?+__^)QHU\)#B)^HV#%)K__^B4T?__
MA<!T=8N#5`$``(D$).BBRO__Z/W+__^+1"0HBWPD/"LX#X6T````B?"-9?1;
M7E]=P^C>RO__B8-4`0``A<`/A(L```")!"3H*,K__V6A`````"N#W/___XL`
MQH#Z!````.FK_O__BX-4`0``B00DZ'#,___I9O___XN#3`$``(7`=`V)!"3H
M!>S__^ET____B?J-@\N9___H]]#__XF#3`$``(7`#X19____Z]:+@^3___^)
M1"0$C8.#F?__B00DZ!_+__^_!````.G5_O__QP0D`0```.CYR/__Z.3+__^+
M!"3#BQPDPXL\),,``````````%6)Y>BXS___R<,``'!S7W-T<FEN9W,@;6ES
M<VEN9PH`)7,O)7,`+@`O<')O8R]C=7)P<F]C+V5X90!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`4$%27U1%35``
M4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`55-%4@!365-414T`+W1M<"\`5$5-4$1)4@!435``55-%4DY!344`)3`R
M>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S:&]R="!R96%D`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`
M,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M90`M+0``)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``
M<&5R;'AS:2YC`````1L#.S`!```E````5(C__W@"```DC/__G`(``%2,__],
M`0``@(S__W0!``"9C?__W`$``-Z-__\<`@``))#__[`"``#\D/___`(``(N2
M__\L`P``%I/__UP#``"XD___C`,``*R4__^\`P``F9;__^P#``#IEO__%`0`
M`%*7__\\!```59?__U`$``"#F?__@`0``+^9__^H!```&YK__^@$``#VG?__
M&`4``$Z>__]$!0``C9[__V`%``!EH/__D`4``)"@__^T!0``3*'__^0%``#+
MJ/__%`8``""K__]$!@``E*O__[`&``#(N/__X`8``".Y__\$!P``-+O__S0'
M```4O?__R`$``!R]__\(`@``)+W__X`&``!PO___/`(``'2___]0`@``>+__
M_V0"```4``````````%Z4@`!?`@!&PP$!(@!```D````'`````"+__\L````
M`$$."(4"0@T%0H8#@P1DPT'&0<4,!`0`+````$0````$B___&0$```!!#@B%
M`D(-!4:'`X8$@P4"4`K#0<9!QT'%#`0$00L`(``````````!>E(``7P(`1L,
M!`2(`0P%"(,%A0*&!(<#````$````"@```!$N___"``````````H````K```
M`+6+__]%`````$$."(4"0@T%1H<#A@2#!7C#0<9!QT'%#`0$`!````!H````
M#+O__P@`````````'````.P```"ZB___8@$```!!#@B%`D(-!4:'`X8$@P40
M````#`$``"R]__\$`````````!`````@`0``'+W__P0`````````$````#0!
M```,O?__!``````````@````2`$``-2%___0`P````X(1@X,2@\+=`1X`#\:
M.RHR)"(0````;`$``(")__\@`````````$@```"``0``;(W__]@`````00X(
MA0)"#05&AP.&!(,%`I(*PT'&0<=!Q0P$!$$+8`K#0<9!QT'%#`0$00M("L-!
MQD''0<4,!`1!"P`L````S`$``/B-__^/`0```$$."(4"0@T%28<#A@2#!74*
MPT'&0<=!Q0P$!$$+```L````_`$``%>/__^+`````$$."(4"0@T%28<#A@2#
M!0)V"L-!QD''0<4,!`1!"P`L````+`(``+*/__^B`````$$."(4"0@T%28<#
MA@2#!0)X"L-!QD''0<4,!`1!"P`L````7`(``"20___T`````$$."(4"0@T%
M3(<#A@2#!0+5"L-!QD''0<4,!`1!"P`L````C`(``.B0___M`0```$$."(4"
M0@T%1H<#A@2#!0,"`0K#0<9!QT'%#`0$00LD````O`(``*62__]0`````$$.
M"(4"0@T%1X,#`D3##01!Q0X$````)````.0"``#-DO__:0````!!#@B%`D(-
M!4B&`X,$`EO#0<9!Q0P$!!`````,`P``#I/__P,`````````+````"`#``#]
MDO__+@(```!!#@B%`D(-!4F'`X8$@P4"A`K#0<9!QT'%#`0$00L`)````%`#
M``#[E/__/`````!!#@B%`D(-!46&`X,$<<-!QD'%#`0$`#P```!X`P``#Y7_
M_UP`````00X(A0)"#05%A@.#!&\*PT'&0<4,!`1%"U(*PT'&0<4,!`1!"T;#
M0<9!Q0P$!``L````N`,``"N5___;`P```$$."(4"0@T%1H<#A@2#!0.?`PK#
M0<9!QT'%#`0$10LH````Z`,``-:8__]8`````$$."(4"0@T%188#@P0"1`K#
M0<9!Q0P$!$$+`!@````4!````IG__S\`````00X(A0)"#05$@P,L````,`0`
M`"69___8`0```$$."(4"0@T%28<#A@2#!0-L`0K#0<9!QT'%#`0$00L@````
M8`0``,V:__\K`````$$."(4"0@T%1(,#8L-!Q0P$!``L````A`0``-2:__^\
M`````$$."(4"0@T%1H<#A@2#!0)+"L-!QD''0<4,!`1%"P`L````M`0``&";
M__]_!P```$$."(4"0@T%28<#A@2#!0,*`PK#0<9!QT'%#`0$00LL````Y`0`
M`*^B__]5`@```$$."(4"0@T%28<#A@2#!0.Y`0K#0<9!QT'%#`0$00LX````
M%`4``-2D__]P`````$$."(4"0@T%1H<#A@2#!6D*PT'&0<=!Q0P$!$$+<L-!
MQD''0<4,!`0````L````4`4``)RV__],`@```$$."(4"0@T%28<#A@2#!0.-
M`0K#0<9!QT'%#`0$00LL````@`4``-RD__\T#0```$$."(4"0@T%28<#A@2#
M!0,9#0K#0<9!QT'%#`0$00L@````L`4``."Q__];`````$$."(4"0@T%1(,#
M`E+#0<4,!`0L````U`4``!>R__\1`@```$$."(4"0@T%1H<#A@2#!0->`0K#
M0<9!QT'%#`0$00LL````!`8``/BS___1`0```$$."(4"0@T%1H<#A@2#!0,W
M`0K#0<9!QT'%#`0$00L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_____`````/____\`````
M``````$````!`````0```*("```!````V@(```$```#O`@```0````X#```/
M````A00```P````@$@``#0```&!)```$````>`$```4```#H"@``!@```)@$
M```*````R@0```L````0````%0`````````#`````+````(```#@`0``%```
M`!$````7````-!```!$```"T#P``$@```(`````3````"````/O__V\````(
M^O__;P0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````[*X`````
M`````````````.RN`````````````$82``!6$@``9A(``'82``"&$@``EA(`
M`*82``"V$@``QA(``-82``#F$@``]A(```83```6$P``)A,``#83``!&$P``
M5A,``&83``!V$P``AA,``)83``"F$P``MA,``,83``#6$P``YA,``/83```&
M%```%A0``"84```V%```1A0``%84``!F%```=A0``(84``"6%```IA0``+84
M``#&%```UA0``.84``#V%```!A4``!85```F%0``-A4``$85``!6%0``9A4`
M`'85``"&%0``EA4``*85``"V%0``QA4``-85``#F%0``]A4``$2Q````L0``
M````````````````````````````````````````````````"E!!4BYP;0H`
M````6$P``$=#0SH@*$YE=$)31"!N8C,@,C`R,S$P,#@I(#$P+C4N,`!'0T,Z
M("AN8C,@,C`R,S$P,#@I(#$P+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C0@
M,C`Q."\Q,2\R-B`Q-SHS-SHT-2!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P
M+6-O;6UO;BYC+'8@,2XR-R`R,#(R+S`V+S(Q(#`V.C4R.C$W('-K<FQL($5X
M<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,S
M(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+E,L=B`Q+C$@,C`Q,"\P
M."\P-R`Q.#HP,3HS,R!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV
M(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,S(&IO97)G($5X<"`D`"1.971"4T0Z
M(&-R=&XN4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,T(&IO97)G($5X<"`D
M``#QSP(`````````````````"`````@````(````"````!L````!````````
M```J*BH@3F\@3&%B96P@4')O=FED960@*BHJ``#QSP(`````````````````
M"`````@````(````"````!L````!```````````J*BH@3F\@3&%B96P@4')O
M=FED960@*BHJ```N<VAS=')T86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E
M;G0`+FYO=&4N;F5T8G-D+G!A>``N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ
M8W(`+F1Y;F%M:6,`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=``N4U5.
M5U]C=&8`````````````````````````````````````````````````````
M``L````!`````@```#0!```T`0``%P```````````````0`````````3````
M!P````(```!,`0``3`$``!@```````````````0`````````)@````<````"
M````9`$``&0!```4```````````````$`````````#<````%`````@```'@!
M``!X`0``(`,```4`````````!`````0````]````"P````(```"8!```F`0`
M`%`&```&`````0````0````0````10````,````"````Z`H``.@*``#*!```
M```````````!`````````$T````)`````@```+0/``"T#P``@`````4`````
M````!`````@```!6````"0```$(````T$```-!```.`!```%````%@````0`
M```(````7P````$````&````(!(``"`2```*```````````````0````````
M`%H````!````!@```#`2```P$@``T`,`````````````$`````0```!E````
M`0````8`````%@```!8``"````````````````@````(````;@````$````&
M````(!8``"`6```X,P`````````````0`````````'0````!````!@```&!)
M``!@20``"@``````````````$`````````!Z`````0````(```!L20``;$D`
M`&Y```````````````0`````````@@````$````"````W(D``-R)```T`0``
M```````````$`````````)`````!`````@```!"+```0BP``-`8`````````
M````!`````````":`````0````,```#8K@``V)X```@```````````````0`
M````````H0````$````#````X*X``.">```(```````````````$````````
M`*@````!`````P```.BN``#HG@``!```````````````!`````````"M````
M!@````,```#LK@``[)X``.`````&``````````0````(````:0````$````#
M````S*\``,R?```T```````````````$````!````+8````!`````P````"P
M````H```_```````````````!`````0```"_`````0````,```#\L```_*``
M`#P```````````````0`````````Q0````@````#````0+$``#BA``!$````
M``````````!``````````,H````!````,``````````XH0``/0``````````
M`````0````$````?`````0```#``````````=:$``%(!``````````````$`
M```!````TP````$``````````````,BB``"/```````````````$````````
I``$````#``````````````!7HP``W0```````````````0``````````
